@@ -12,15 +12,16 @@
 
 package DB::DbgrCommon;
 
+use strict;
 use DB::CGI::Util qw();
 use DB::MIME::Base64 qw();
 use File::Basename qw(dirname);
 use Encode;
 
-$VERSION = 0.10;
 require Exporter;
-@ISA = qw(Exporter);
-@EXPORT = qw(encodeData
+our @ISA = qw(Exporter);
+our @EXPORT = qw(
+	     encodeData
 	     endPropertyTag getCommonType
              isFloat
 	     makeErrorResponse namespaceAttr
@@ -63,12 +64,13 @@ require Exporter;
 	     NV_UNSET_FLAG
 
 	     %settings
+	     setLogFH
 	     dblog
 	     );
 
 # Leave the other parts of the logger unexported.
 
-@EXPORT_OK = qw();
+our @EXPORT_OK = qw();
 
 # Error codes
 
@@ -108,8 +110,11 @@ use constant NV_UNSET_FLAG => 3;
 
 # Real simple logging
 
-$doLogging = 0;
-$logFH = undef;
+my $doLogging = 0;
+my $logFH = undef;
+my $OUT = undef;
+our $ldebug;
+our %settings;
 
 # enableLogger(filename || filehandle);
 # dies if it fails to do logging
@@ -173,27 +178,28 @@ sub dblog {
     }
 }
 
-# our ($OUT, $ldebug);
+sub setLogFH {
+    $logFH = $_[0];
+}
 
 sub setDefaultOutput {
     $OUT = shift;
 }
 
-sub encodeData($;$) {
+sub encodeData($$) {
     my ($str, $encoding) = @_;
     my $finalStr;
-    my $currDataEncoding = defined $encoding ? $encoding : $settings{data_encoding}->[0];
     $finalStr = $str;
     local $@;
     eval {
-	if ($currDataEncoding eq 'none' || $currDataEncoding eq 'binary') {
+	if ($encoding eq 'none' || $encoding eq 'binary') {
 	    $finalStr = $str;
-	} elsif ($currDataEncoding eq 'urlescape') {
+	} elsif ($encoding eq 'urlescape') {
 	    $finalStr = DB::CGI::Util::escape($str);
-	} elsif ($currDataEncoding eq 'base64') {
+	} elsif ($encoding eq 'base64') {
 	    $finalStr = DB::MIME::Base64::encode_base64($str);
 	} else {
-	    dblog("Converting $str with unknown encoding of $currDataEncoding\n") if $ldebug;
+	    dblog("Converting $str with unknown encoding of $encoding\n") if $ldebug;
 	    $finalStr = $str;
 	}
     };
@@ -201,9 +207,9 @@ sub encodeData($;$) {
 	my $str = safe_dump($str);
 	if ($@) {
 	    $str = (substr($str, 0, 100) . '...') if length($str) > 100;
-	    dblog("encodeData('$str') => [$@]\n");
+	    dblog("encodeData('$str') => [$@]\n") if $ldebug;
 	} else {
-	    dblog("encodeData('$str') => ['$finalStr']\n");
+	    dblog("encodeData('$str') => ['$finalStr']\n") if $ldebug;
 	}
     }
     return $finalStr;
@@ -288,9 +294,9 @@ sub namespaceAttr() {
 }
 
 sub printWithLength {
-  local $mainArg = shift;
-  local $argLen = length($mainArg);
-  local $finalStr = sprintf("%d\0%s\0", $argLen, $mainArg);
+  my $mainArg = shift;
+  my $argLen = length($mainArg);
+  my $finalStr = sprintf("%d\0%s\0", $argLen, $mainArg);
 ####   local $SIG{__WARN__} = sub {
 ####       my $msg = shift;
 ####       dblog("**************** Warn hook: {$msg}");
