@@ -12,10 +12,12 @@
 
 package DB::DbgrProperties;
 
-$VERSION = 0.10;
+use strict qw(vars subs);
+
+our $VERSION = 0.10;
 require Exporter;
-@ISA = qw(Exporter);
-@EXPORT = qw(
+our @ISA = qw(Exporter);
+our @EXPORT = qw(
 	     doPropertySetInfo
 	     emitContextNames
 	     emitContextProperties
@@ -25,13 +27,12 @@ require Exporter;
 	     getContextProperties
 	     getFullPropertyInfoByValue
 	     getPropertyInfo
-	     sortArrayOfNames
 	     GlobalVars
 	     LocalVars
 	     FunctionArguments
 	     PunctuationVariables
 	     );
-@EXPORT_OK = ();
+our @EXPORT_OK = ();
 
 use overload;
 
@@ -55,19 +56,21 @@ use constant GlobalVars => 1;
 use constant FunctionArguments => 2;
 use constant PunctuationVariables => 3;
 
-$ldebug = 0;
+our $ldebug = 0;
 
 # Private Data
 
-%contextProperties = (Globals => GlobalVars,
-		      Locals => LocalVars,
-		      Arguments => FunctionArguments,
-		      Special => PunctuationVariables);
-@contextProperties = sort { $contextProperties{$a} <=> $contextProperties{$b} } keys %contextProperties;
+my %contextProperties = (
+    Globals => GlobalVars,
+    Locals => LocalVars,
+    Arguments => FunctionArguments,
+    Special => PunctuationVariables,
+);
+my @contextProperties = sort { $contextProperties{$a} <=> $contextProperties{$b} } keys %contextProperties;
 
-@_punctuationVariables = ('$_', '$?', '$@', '$.', '@+', '@-', '$+', '$!', '$$', '$0');
+my @_punctuationVariables = ('$_', '$?', '$@', '$.', '@+', '@-', '$+', '$!', '$$', '$0');
 # $`, $& and $' are special-cased to avoid the performance penalty
-@_rxPunctuationVariables = ('`', '&', '\'');
+my @_rxPunctuationVariables = ('`', '&', '\'');
 
 # Exported subs
 
@@ -114,7 +117,7 @@ sub emitContextNames($$) {
 		      $transactionID);
     # todo: the spec suggests that locals be the default,
     # but globals (package globals) make more sense for Perl.
-    for ($i = 0; $i <= $#contextProperties; $i++) {
+    for (my $i = 0; $i <= $#contextProperties; $i++) {
 	$res .= sprintf(qq(<context name="%s" id="%d" />\n),
 			$contextProperties[$i],
 			$i);
@@ -260,13 +263,13 @@ sub _truncateIfNecessary {
     if ($maxDataSize > 0) {
 	$maxDataSize -= 2 if $stripOuterBrackets;
 	if (length($res) > $maxDataSize) {
-	    dblog("_truncateIfNecessary: Have length(\$res) = ", length($res), " > $maxDataSize");
+	    dblog("_truncateIfNecessary: Have length(\$res) = ", length($res), " > $maxDataSize") if $ldebug;
 	    if ($maxDataSize >= 3) {
 		$res = substr($res, 0, ($maxDataSize - 3)) . "...";
 	    } else {
 		$res = substr($res, 0, $maxDataSize);
 	    }
-	    dblog("_truncateIfNecessary: After: length(\$res) = ", length($res));
+	    dblog("_truncateIfNecessary: After: length(\$res) = ", length($res)) if $ldebug;
 	}
     }
     return $res;
@@ -426,7 +429,7 @@ sub _getFullPropertyInfoByValue {
 		$hasChildren = $numChildren && 1;
 		if ($className) {
 		    $typeString = $className;
-		    if ($maxDataSize >= 0 && $dataSize > $maxDataSize) {
+		    if ($maxDataSize >= 0 && length($val) > $maxDataSize) {
 			# dblog("getFullPropertyInfoByValue: truncating data down to $maxDataSize bytes:\n[$val]\n");
 			$val = substr($val, 0, $maxDataSize);
 		    }
@@ -613,12 +616,12 @@ sub analyzeVal($) {
     } elsif (overload::Overloaded($val)) {
 	my $overloadedRefStr;
 	if ($overloadedRefStr = overload::StrVal($val)) {
-	    dblog('qqq:analyzeVal ' . __LINE__);
-	    dblog("analyzeVal -- overloaded [$val] => $overloadedRefStr");
+	    dblog('qqq:analyzeVal ' . __LINE__) if $ldebug;
+	    dblog("analyzeVal -- overloaded [$val] => $overloadedRefStr") if $ldebug;
 	    my $className;
 	    if ($overloadedRefStr =~ /^(.*)=/) {
 		$className = $1;
-		dblog("  \$className = $className, \$overloadedRefStr = $overloadedRefStr");
+		dblog("  \$className = $className, \$overloadedRefStr = $overloadedRefStr") if $ldebug;
 		if ($overloadedRefStr =~ /=HASH\(0x\w+\)/) {
 		    return ('HASH', scalar keys %$val, $className, $overloadedRefStr);
 		} elsif ($overloadedRefStr =~ /=ARRAY\(0x\w+\)/) {
@@ -627,10 +630,10 @@ sub analyzeVal($) {
 		    return ('SCALAR', 0, $className, $overloadedRefStr);
 		}
 	    }
-	    dblog("Could pull className out of refstr [$overloadedRefStr]");
+	    dblog("Could pull className out of refstr [$overloadedRefStr]") if $ldebug;
 	}
 	# It's some other kind of bizarre overloaded operator.
-	dblog('qqq:analyzeVal ' . __LINE__);
+	dblog('qqq:analyzeVal ' . __LINE__) if $ldebug;
 	return ('SCALAR', 0, $overloadedRefStr);
     } else {
 	# Return whatever it is.
@@ -639,12 +642,6 @@ sub analyzeVal($) {
     }
 }
 
-sub sortArrayOfNames {
-    my ($a1, $a2) = split(//, $a, 2);
-    my ($b1, $b2) = split(//, $b, 2);
-    return ($a2 cmp $b2 || $a1 cmp $b1);
-}
-
 #############################################################################
 
 # Internal subs
